camelot.camelot.model.authentication.DirectedDirector

Package camelot :: Package camelot :: Package model :: Module authentication :: Class DirectedDirector |
[hide private]
[frames] | no frames]

# Class DirectedDirector

source code

Relation from a directed organization to a director

Nested Classes | [hide private]
| DirectorAdmin
| DirectedAdmin

Class Variables | [hide private]
| established_from = `ManyToOne('Organization', required= True, o`...``
| established_to = `ManyToOne('Person', required= True, ondelete=`...``
| title = `Field(Unicode(256))`
| representing = `OneToMany('RepresentedRepresentor', inverse= 'e`...``
Inherited from `PartyRelationship`: `comment`, `from_date`, `thru_date`

Class Variable Details | [hide private]

  ### established_from Value:
      ManyToOne('Organization', required= True, ondelete= 'cascade', onupdat
      e= 'cascade')

  ### established_to Value:
      ManyToOne('Person', required= True, ondelete= 'cascade', onupdate= 'ca
      scade')

  ### representing Value:
      OneToMany('RepresentedRepresentor', inverse= 'established_to')